==> matex_dart-0.2.0.tar.gz: lib/core/calculators/required_margin/required_margin.dart <==
import 'package:decimal/decimal.dart';
import 'package:matex_dart/matex_dart.dart';

class MatexRequiredMarginCalculatorCore
    extends MatexBaseCalculator<MatexRequiredMarginCalculatorCore, double>
    with
        MatexLotCoreMixin<MatexRequiredMarginCalculatorCore, double>,
        MatexPipValueCoreMixin<MatexRequiredMarginCalculatorCore, double>,
        MatexRequiredMarginCoreMixin<MatexRequiredMarginCalculatorCore,
            double> {
  MatexRequiredMarginCalculatorCore({
    MatexBaseCoreState defaultState,
    List<MatexStateValidator> validators,
  }) : super(
          defaultState: defaultState,
          validators: validators ?? requiredMarginValidators,
        );

  @override
  MatexBaseCoreState get defaultCalculatorState => kInitialRequiredMarginState;

  @override
  double value() {
    if (result != null) {
      return result;
    }

    final positionSize = validState.positionSize;
    final tradingPairExchangeRate = validState.tradingPairExchangeRate;
    final leverage = validState.leverage;
    final baseListedSecond = validState.baseListedSecond;
    final baseExchangeRate = validState.baseExchangeRate;

    final rate = baseExchangeRate > 0
        ? baseExchangeRate
        : baseListedSecond
            ? tradingPairExchangeRate
            : 1;

    return (result = (Decimal.parse(positionSize.toString()) /
            Decimal.parse(leverage.toString()) *
            Decimal.parse(rate.toString()))
        .toDouble());
  }
}

MatexRequiredMarginCalculatorCore requiredMargin({
  MatexBaseCoreState defaultState,
  List<MatexStateValidator> validators,
}) =>
    MatexRequiredMarginCalculatorCore(
      defaultState: defaultState,
      validators: validators,
    );

==> matex_dart-0.2.6.tar.gz: lib/core/calculators/required_margin/required_margin.dart <==
import 'package:decimal/decimal.dart';
import 'package:matex_dart/matex_dart.dart';

class MatexRequiredMarginCalculatorCore
    extends MatexBaseCalculator<MatexRequiredMarginCalculatorCore, double>
    with
        MatexLotCoreMixin<MatexRequiredMarginCalculatorCore, double>,
        MatexPipValueCoreMixin<MatexRequiredMarginCalculatorCore, double>,
        MatexRequiredMarginCoreMixin<MatexRequiredMarginCalculatorCore,
            double> {
  MatexRequiredMarginCalculatorCore({
    MatexBaseCoreState defaultState,
    List<MatexStateValidator> validators,
  }) : super(
          defaultState: defaultState,
          validators: validators ?? requiredMarginValidators,
        );

  @override
  MatexBaseCoreState get defaultCalculatorState => kInitialRequiredMarginState;

  @override
  double value() {
    if (result != null) {
      return result;
    }

    // TODO: Workaround before using counterAccountPairExchangeRate
    final tradingPairExchangeRate = validState.tradingPairExchangeRate;
    final baseListedSecond = validState.baseListedSecond;
    final baseExchangeRate = validState.baseExchangeRate;
    final positionSize = validState.positionSize;
    final decimalLeverage = Decimal.parse(validState.leverage.toString());
    final rate = baseExchangeRate > 0 ? baseExchangeRate : 1;

    if (!baseListedSecond) {
      return (result = (Decimal.parse(positionSize.toString()) *
              Decimal.parse(tradingPairExchangeRate.toString()) /
              decimalLeverage *
              Decimal.parse(rate.toString()))
          .toDouble());
    }

    return (result = (Decimal.parse(positionSize.toString()) *
            Decimal.parse(tradingPairExchangeRate.toString()) /
            decimalLeverage /
            Decimal.one)
        .toDouble());
  }
}

MatexRequiredMarginCalculatorCore requiredMargin({
  MatexBaseCoreState defaultState,
  List<MatexStateValidator> validators,
}) =>
    MatexRequiredMarginCalculatorCore(
      defaultState: defaultState,
      validators: validators,
    );
